@@ -20,8 +20,8 @@ class TransferMoneyToCard(QiwiAPIMethod[PaymentInfo]):
     }
 
     private_card_id: str = Field(..., path_runtime_value=True)
-    amount: Union[int, float]
-    card_number: str
+    amount: Union[int, float] = Field(..., scheme_path="sum.amount")
+    card_number: str = Field(..., scheme_path="fields.account")
     kwargs: Dict[str, Any] = {}  # parameters for cards with ID 1960, 21012
 
     def build_request(self, **url_format_kw: Any) -> "Request":
