@@ -1,10 +1,8 @@
-from __future__ import annotations
+from typing import Optional, Union
 
-from typing import Union, Optional
+from pydantic import BaseModel, Field, validator, BaseConfig
 
-from pydantic import BaseModel, validator, Field
-
-from glQiwiApi.types.base import HashableBase
+from glQiwiApi.types.base import Base, HashableBase
 
 
 class CurrencyModel(HashableBase):
@@ -17,8 +15,15 @@ class CurrencyModel(HashableBase):
     symbol_native: str
     iso_format: Optional[str] = Field(..., alias="isoformat")
 
+    def __str__(self) -> str:
+        return self.code
 
-class CurrencyAmount(BaseModel):
+    class Config(BaseConfig):
+        frozen = True
+        allow_mutation = False
+
+
+class AmountWithCurrency(Base):
     amount: float
     currency: Union[CurrencyModel, str]  # string if currency util couldn't parse it
 
@@ -34,7 +39,7 @@ class CurrencyAmount(BaseModel):
         return Currency.get(str(v))
 
 
-class HashableSum(HashableBase, CurrencyAmount):
+class HashableSum(HashableBase, AmountWithCurrency):
     ...
 
 
@@ -43,7 +48,7 @@ class PlainAmount(BaseModel):
     currency: str
 
 
-class HashableOptionalSum(HashableBase, PlainAmount):
+class HashablePlainAmount(HashableBase, PlainAmount):
     ...
 
 
